FlowSampleExpanded

Struct FlowSampleExpanded 

pub struct FlowSampleExpanded {
    pub sequence_number: u32,
    pub source_id: DataSourceExpanded,
    pub sampling_rate: u32,
    pub sample_pool: u32,
    pub drops: u32,
    pub input: InterfaceExpanded,
    pub output: InterfaceExpanded,
    pub flow_records: Vec<FlowRecord>,
}
Expanded flow sample - Format (0,3)

Flow sample with expanded encoding for large interface indices (>= 2^24).

XDR Definition (sFlow v5)

/* Format of a single expanded flow sample */
/* opaque = sample_data; enterprise = 0; format = 3 */

struct flow_sample_expanded {
   unsigned int sequence_number;  /* Incremented with each flow sample
                                     generated by this sFlow Instance. */
   sflow_data_source_expanded source_id; /* sFlowDataSource */
   unsigned int sampling_rate;    /* sFlowPacketSamplingRate */
   unsigned int sample_pool;      /* Total number of packets that could have been
                                     sampled (i.e. packets skipped by sampling process
                                     + total number of samples) */
   unsigned int drops;            /* Number of times that the sFlow agent detected
                                     that a packet marked to be sampled was dropped
                                     due to lack of resources. */
   interface_expanded input;      /* Input interface */
   interface_expanded output;     /* Output interface */
   flow_record flow_records<>;    /* Information about sampled packet */
}

ERRATUM: Sequence number clarified as incremented per “sFlow Instance” instead of “source_id”.

Fields

sequence_number: u32

Sequence number incremented with each flow sample generated by this sFlow Instance ERRATUM: Clarified as “sFlow Instance” instead of “source_id”

source_id: DataSourceExpanded

Expanded sFlow data source identifier

sampling_rate: u32

Sampling rate (1 in N packets)

sample_pool: u32

Total packets that could have been sampled

drops: u32

Number of dropped samples due to lack of resources

input: InterfaceExpanded

Input interface (expanded)

output: InterfaceExpanded

Output interface (expanded)

flow_records: Vec<FlowRecord>

Flow records describing the sampled packet