BroadcomPortBuffers

Struct BroadcomPortBuffers 

pub struct BroadcomPortBuffers {
    pub ingress_uc_pc: i32,
    pub ingress_mc_pc: i32,
    pub egress_uc_pc: i32,
    pub egress_mc_pc: i32,
    pub egress_queue_uc_pc: Vec<i32>,
    pub egress_queue_mc_pc: Vec<i32>,
}
Broadcom Port Buffer Utilization - Format (4413,2)

Port level buffer utilization statistics from Broadcom switch ASICs

XDR Definition (sFlow Broadcom Buffers)

/* Port level buffer utilization */
/* buffers_used metrics represent peak buffers used since last export */
/* opaque = counter_data; enterprise = 4413; format = 2 */
struct bst_port_buffers {
  percentage ingress_uc_pc;         /* ingress unicast buffers utilization */
  percentage ingress_mc_pc;         /* ingress multicast buffers utilization */
  percentage egress_uc_pc;          /* egress unicast buffers utilization */
  percentage egress_mc_pc;          /* egress multicast buffers utilization */
  percentage egress_queue_uc_pc<8>; /* per egress queue unicast buffers utilization */
  percentage egress_queue_mc_pc<8>; /* per egress queue multicast buffers utilization*/
}

Fields

ingress_uc_pc: i32

Ingress unicast buffers percentage utilization (in hundredths of a percent)

ingress_mc_pc: i32

Ingress multicast buffers percentage utilization (in hundredths of a percent)

egress_uc_pc: i32

Egress unicast buffers percentage utilization (in hundredths of a percent)

egress_mc_pc: i32

Egress multicast buffers percentage utilization (in hundredths of a percent)

egress_queue_uc_pc: Vec<i32>

Per egress queue unicast buffers percentage utilization (up to 8 queues)

egress_queue_mc_pc: Vec<i32>

Per egress queue multicast buffers percentage utilization (up to 8 queues)