VirtualDiskIo

Struct VirtualDiskIo 

pub struct VirtualDiskIo {
    pub capacity: u64,
    pub allocation: u64,
    pub available: u64,
    pub rd_req: u32,
    pub rd_bytes: u64,
    pub wr_req: u32,
    pub wr_bytes: u64,
    pub errs: u32,
}
Virtual Disk I/O - Format (0,2103)

Virtual domain disk statistics

XDR Definition (sFlow Host)

/* Virtual Domain Disk statistics */
/* See libvirt, struct virDomainBlockInfo */
/* See libvirt, struct virDomainBlockStatsStruct */
/* opaque = counter_data; enterprise = 0; format = 2103 */

struct virt_disk_io {
    unsigned hyper capacity;   /* logical size in bytes */
    unsigned hyper allocation; /* current allocation in bytes */
    unsigned hyper physical;   /* physical size in bytes of the container of the backing image */
    unsigned int rd_req;       /* number of read requests */
    unsigned hyper rd_bytes;   /* number of read bytes */
    unsigned int wr_req;       /* number of write requests */
    unsigned hyper wr_bytes;   /* number of written bytes */
    unsigned int errs;         /* read/write errors */
}

ERRATUM: Field name changed from available to physical, and comment references corrected from virtDomainBlockInfo/virtDomainBlockStatsStruct to virDomainBlockInfo/virDomainBlockStatsStruct.

Fields

capacity: u64

Capacity in bytes

allocation: u64

Allocation in bytes

available: u64

Physical size in bytes of the container of the backing image (spec: physical) ERRATUM: Field renamed from available (remaining free bytes) to physical

rd_req: u32

Read requests

rd_bytes: u64

Bytes read

wr_req: u32

Write requests

wr_bytes: u64

Bytes written

errs: u32

Errors