ExtendedNatPort

Struct ExtendedNatPort 

pub struct ExtendedNatPort {
    pub src_port: u32,
    pub dst_port: u32,
}
Extended NAT Port Data - Format (0,1020)

Layer 4 port translation information for NAT

XDR Definition (sFlow Port NAT)

/* Extended NAT L4 Port Data
   Packet header reports ports as seen at the sFlowDataSource.
   The extended_nat_port structure reports on translated source and/or
   destination layer 4 (TCP/UDP) ports for this packet. If port was not
   translated it should be equal to that reported for the header. */
/* opaque = flow_data; enterprise = 0; format = 1020 */

struct extended_nat_port {
     unsigned int src_port;            /* Source port */
     unsigned int dst_port;            /* Destination port */
}

Fields

src_port: u32

Translated source port

dst_port: u32

Translated destination port