Transaction

Struct Transaction 

pub struct Transaction {
    pub direction: ServiceDirection,
    pub wait: u32,
    pub duration: u32,
    pub status: TransactionStatus,
    pub bytes_received: u64,
    pub bytes_sent: u64,
}
Transaction - Format (0,2000)

Generic application transaction record sampled upon completion

XDR Definition (sFlow Discussion)

/* Generic Application Transaction record */
/* Every Application Transaction sample must start with a generic transaction record */
/* opaque = flow_data; enterprise = 0; format = 2000 */
struct transaction {
    service_direction direction; /* was this transaction observed by the server or the client */
    unsigned int wait;           /* time in microseconds that transaction was queued
                                    before processing started */
    unsigned int duration;       /* time in microseconds from start of processing to completion */
    status_value status;         /* status of transaction */
    unsigned hyper bytes_received; /* bytes received */
    unsigned hyper bytes_send;   /* bytes sent */
}

Fields

direction: ServiceDirection

Was this transaction observed by the server or the client

wait: u32

Time in microseconds that transaction was queued before processing started

duration: u32

Time in microseconds from start of processing to completion

status: TransactionStatus

Status of transaction

bytes_received: u64

Bytes received

bytes_sent: u64

Bytes sent (spec: bytes_send)